@@ -1,10 +1,14 @@
-""" A module for altering settings. """
+"""
+Altering settings of working environment.
+"""
 
 import os
 
 import numpy as np
 import pandas as pd
 
+""" NumPy -------------------------------------------------------------------------- """
+
 
 def np_preferences(reset=False):
     """
@@ -12,6 +16,12 @@ def np_preferences(reset=False):
 
     :param reset: whether to reset to default settings, defaults to ``False``
     :type reset: bool
+
+    **Example**::
+
+        >>> from pyhelpers.settings import np_preferences
+
+        >>> np_preferences()
     """
 
     if not reset:
@@ -20,12 +30,24 @@ def np_preferences(reset=False):
         np.core.arrayprint._line_width = 80  # 75
 
 
-def pd_preferences(reset=False):
+""" Pandas ------------------------------------------------------------------------- """
+
+
+def pd_preferences(reset=False, ignore_future_warning=True):
     """
     Set preferences for displaying results.
 
     :param reset: whether to reset to default settings, defaults to ``False``
     :type reset: bool
+    :param ignore_future_warning: whether to ignore/suppress future warnings,
+        defaults to ``True``
+    :type ignore_future_warning: bool
+
+    **Example**::
+
+        >>> from pyhelpers.settings import pd_preferences
+
+        >>> pd_preferences()
     """
 
     if not reset:
@@ -40,9 +62,15 @@ def pd_preferences(reset=False):
         pd.set_option('mode.chained_assignment', None)
         # pandas.set_option('display.float_format', lambda x: '%.4f' % x)
     else:
+        if ignore_future_warning:
+            import warnings
+            warnings.simplefilter(action='ignore', category=FutureWarning)
         pd.reset_option('all')
 
 
+""" Matplotlib --------------------------------------------------------------------- """
+
+
 def mpl_preferences(reset=False, font_name=None):
     """
     Set preferences for plotting.
@@ -50,18 +78,15 @@ def mpl_preferences(reset=False, font_name=None):
     :param reset: whether to reset to default settings, defaults to ``False``
     :type reset: bool
     :param font_name: name of a font to be used, defaults to ``None``
-    :type font_name: str, None
+    :type font_name: None or str
 
-    .. note::
+    **Example**::
 
-        Get a list of supported file formats for `matplotlib.pyplot.savefig` function
+        >>> from pyhelpers.settings import mpl_preferences
 
-        .. code-block:: python
+        >>> mpl_preferences()
 
-            import matplotlib.pyplot as plt
-
-            plt.gcf().canvas.get_supported_filetypes()  # `gcf` is short for 'get current fig' manager
-            plt.gcf().canvas.get_supported_filetypes_grouped()
+        >>> mpl_preferences(font_name='Times New Roman')
     """
 
     import matplotlib.pyplot as plt
@@ -75,7 +100,8 @@ def mpl_preferences(reset=False, font_name=None):
         if font_name:  # Use the font, 'Cambria'
             if os.path.isfile(matplotlib.font_manager.findfont(font_name)):
                 # Set 'font.family' to 'serif', then matplotlib will use that list
-                plt.rcParams['font.family'], serif_fonts = 'serif', plt.rcParams['font.serif']
+                plt.rcParams['font.family'] = 'serif'
+                serif_fonts = plt.rcParams['font.serif']
                 if font_name not in serif_fonts:
                     plt.rcParams['font.serif'] = [font_name] + plt.rcParams['font.serif']
                 else:
@@ -88,6 +114,9 @@ def mpl_preferences(reset=False, font_name=None):
         plt.style.use('default')
 
 
+""" GDAL --------------------------------------------------------------------------- """
+
+
 def gdal_configurations(reset=False, max_tmpfile_size=5000):
     """
     Set GDAL configurations.
@@ -96,6 +125,12 @@ def gdal_configurations(reset=False, max_tmpfile_size=5000):
     :type reset: bool
     :param max_tmpfile_size: maximum size of the temporary file, defaults to ``5000``
     :type max_tmpfile_size: int
+
+    **Example**::
+
+        >>> from pyhelpers.settings import gdal_configurations
+
+        >>> gdal_configurations()
     """
 
     import gdal
@@ -107,7 +142,8 @@ def gdal_configurations(reset=False, max_tmpfile_size=5000):
         gdal.SetConfigOption('OSM_USE_CUSTOM_INDEXING', 'YES')
         # Whether to compress nodes in temporary DB. Defaults to NO.
         gdal.SetConfigOption('OSM_COMPRESS_NODES', 'YES')
-        # Maximum size in MB of in-memory temporary file. If it exceeds that value, it will go to disk. Defaults to 100.
+        # Maximum size in MB of in-memory temporary file.
+        # If it exceeds that value, it will go to disk. Defaults to 100.
         gdal.SetConfigOption('OSM_MAX_TMPFILE_SIZE', str(max_tmpfile_size))
     else:
         gdal.SetConfigOption('OGR_INTERLEAVED_READING', 'NO')
